@@ -1347,7 +1347,7 @@ class Database:
                     df = df.rename(columns={'contract_month':'year_month'})
                     df['year_month'] = df['year_month'].str.replace('-','', regex=False)
 
-                    if 'w' in deri:
+                    if 'wo' in code:
                         df['year_month'] = pd.to_datetime(df['year_month'], format='%d%b%y')
                         df = df.sort_values(by=['date','year_month'])
                         df['year_month'] = df['year_month'].dt.strftime('%d%b%y')
